package com.slibra.business.service.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.slibra.business.domain.*;
import com.slibra.business.mapper.*;
import com.slibra.business.req.AiChatReq;
import com.slibra.business.req.AiChatRes;
import com.slibra.business.req.ChatReq;
import com.slibra.business.req.WorkOrderReq;
import com.slibra.business.res.*;
import com.slibra.business.service.IFrontService;
import com.slibra.common.DecimalUtils;
import com.slibra.common.core.domain.TXinyiDaily;
import com.slibra.common.core.redis.RedisCache;
import com.slibra.common.enums.BusinessEnum;
import com.slibra.common.exception.ServiceException;
import com.slibra.common.utils.DateUtils;
import com.slibra.common.utils.SecurityUtils;
import com.slibra.common.utils.StringUtils;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.connection.stream.RecordId;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

import java.math.BigDecimal;
import java.math.RoundingMode;
import java.time.LocalDate;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.*;

import static com.slibra.common.constant.MyConstants.*;
import static com.slibra.common.utils.DateUtils.getAllDatesBetween;


@Service
@Slf4j
public class FrontServiceImpl implements IFrontService {

    @Autowired
    private TCutOffWaterMapper cutOffWaterMapper;

    @Autowired
    private TUserInfoMapper  userInfoMapper;




    @Override
    public AiChatRes queryBusinessInfo(AiChatReq aiChatReq) {
        AiChatRes aiChatRes = AiChatRes.builder().build();
        HashMap<String, Object> map = new HashMap<>();
        map.put("contents", this.getBussinessDataByAiChatReq(aiChatReq));
        aiChatRes.setData(map);
        //大模型传过来的，再返回给大模型
        aiChatRes.setUserId(aiChatReq.getUserId());
        aiChatRes.setNodeId(aiChatReq.getNodeId());
        aiChatRes.setSessionId(aiChatReq.getSessionId());
        aiChatRes.setCode("0");
        //返回结果
        return aiChatRes;
    }

    private Object getBussinessDataByAiChatReq(AiChatReq aiChatReq) {
        //判断不同的业务类型，返回不同的数据
        String method = aiChatReq.getMethod();

        String phone = aiChatReq.getUserId();
        String asrText = aiChatReq.getAsrText();

        //基于userId关联用户所在小区的停水信息
        if(BusinessEnum.AiChatReqEnum.water_info.getCode().equals(method)){
//            return this.cutOffWaterMapper.getCutOffWaterByUserPhone(phone);
            //通过手机号获取对应的小区的名字，一个手机号只能查询到一个
            List<TUserInfo> tUserInfos = this.userInfoMapper.selectTUserInfoList(TUserInfo.builder().phone(phone).build());
            if(!CollectionUtils.isEmpty(tUserInfos)){
                return this.cutOffWaterMapper.getCutOffWaterByNeighbourhoodName(tUserInfos.get(0).getNeighbourhoodName());
            }
        }
        //基于用户输入的小区信息，查询停水信息
        if(BusinessEnum.AiChatReqEnum.water_loc_info.getCode().equals(method)){
            return this.cutOffWaterMapper.getCutOffWaterByNeighbourhoodName(asrText);
        }
        //基于userid查询用户户号信息
        if(BusinessEnum.AiChatReqEnum.user_info.getCode().equals(method)){
            return this.userInfoMapper.selectTUserInfoList(TUserInfo.builder().phone(phone).build());
        }
        //基于用户输入手机号信息查询用户户号信息
        if(BusinessEnum.AiChatReqEnum.user_phone_info.getCode().equals(method)){
            return this.userInfoMapper.selectTUserInfoList(TUserInfo.builder().userNo(asrText).build());
        }
        //基于userId查询水费信息
        if(BusinessEnum.AiChatReqEnum.fee_info.getCode().equals(method)){
            List<TUserInfo> tUserInfos = this.userInfoMapper.selectTUserInfoList(TUserInfo.builder().phone(phone).build());
            List<FeeInfo> feeInfos = new ArrayList<>();
            if(!CollectionUtils.isEmpty(tUserInfos)){
                for (TUserInfo tUserInfo : tUserInfos) {
                    FeeInfo feeInfo = new FeeInfo();
                    BeanUtils.copyProperties(tUserInfo, feeInfo);
                    feeInfos.add(feeInfo);
                }
            }
            return feeInfos;
        }
        //基于用户输入输入户号查询水费信息
        if(BusinessEnum.AiChatReqEnum.fee_user_info.getCode().equals(method)){
            List<TUserInfo> tUserInfos = this.userInfoMapper.selectTUserInfoList(TUserInfo.builder().userNo(asrText).build());
            List<FeeInfo> feeInfos = new ArrayList<>();
            if(!CollectionUtils.isEmpty(tUserInfos)){
                for (TUserInfo tUserInfo : tUserInfos) {
                    FeeInfo feeInfo = new FeeInfo();
                    BeanUtils.copyProperties(tUserInfo, feeInfo);
                    feeInfos.add(feeInfo);
                }
            }
            return feeInfos;
        }
        return null;

    }
}
